'use strict';

var Builder = require('./Builder-fc418b7c.js');

var ResourceDecorator = (function () {
    function ResourceDecorator() {
    }
    ResourceDecorator.prototype.Resource = function (constructor) {
        var target = constructor.prototype;
        if (!(target instanceof Builder.BuildableResource)) {
            throw new Error("Target class has to extend BuildableResource in order to use this decorator.");
        }
        if (!target.constructor) {
            throw new Error("Target class must have a constructor with no arguments.");
        }
    };
    ResourceDecorator.prototype.Alias = function (alias) {
        return function (target, name) {
            var _a;
            (_a = target.buildConfig) === null || _a === void 0 ? void 0 : _a.alias(alias, name.toString());
        };
    };
    ResourceDecorator.prototype.Transform = function (transformerIn, transformerOut) {
        return function (target, name) {
            var _a;
            (_a = target.buildConfig) === null || _a === void 0 ? void 0 : _a.transform(name, transformerIn, transformerOut);
        };
    };
    ResourceDecorator.prototype.Required = function (target, name) {
        var _a;
        (_a = target.buildConfig) === null || _a === void 0 ? void 0 : _a.require(name.toString());
    };
    ResourceDecorator.prototype.Ignore = function (target, name) {
        var _a;
        (_a = target.buildConfig) === null || _a === void 0 ? void 0 : _a.ignore(name.toString());
    };
    ResourceDecorator.prototype.ListOf = function (resource) {
        return function (target, name) {
            var _a;
            (_a = target.buildConfig) === null || _a === void 0 ? void 0 : _a.listType(name, new resource());
        };
    };
    return ResourceDecorator;
}());
var resourceDecorator = new ResourceDecorator();
var Resource = resourceDecorator.Resource;
var Alias = resourceDecorator.Alias;
var Transform = resourceDecorator.Transform;
var Ignore = resourceDecorator.Ignore;
var Required = resourceDecorator.Required;
var ListOf = resourceDecorator.ListOf;

var decorators = /*#__PURE__*/Object.freeze({
    __proto__: null,
    Resource: Resource,
    Alias: Alias,
    Transform: Transform,
    Ignore: Ignore,
    Required: Required,
    ListOf: ListOf
});

exports.Alias = Alias;
exports.Ignore = Ignore;
exports.ListOf = ListOf;
exports.Required = Required;
exports.Resource = Resource;
exports.Transform = Transform;
exports.decorators = decorators;
